# -*- coding: utf-8 -*-

"""Top-level package for tomlq."""

__author__ = """Max Dymond"""
__email__ = 'cmeister2@gmail.com'
__version__ = '0.1.0'


import yq


def main():
    """Call through to the tq_cli() command that exists in yq."""
    yq.tq_cli()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `tomlq` package."""

import pytest
import sys
from mock import patch
import tomlq


def test_run():
    testargs = ["tomlq", "-h"]
    with patch.object(sys, 'argv', testargs):
        with pytest.raises(SystemExit):
            tomlq.main()
